 SuperSCAD: Cone

SuperSCAD widgets for cones and cylinders with smooth edges.

<table>
<thead>
<tr>
<th>Legal</th>
<th>Release</th>
<th>Code</th>
</tr>
</thead>
<tbody>
<tr>
<td>
<a href="https://pypi.org/project/Super-SCAD-Cone/" target="_blank"><img alt="PyPI - License" src="https://img.shields.io/pypi/l/Super-SCAD-Cone">
</a>
</td>
<td>
<a href="https://badge.fury.io/py/Super-SCAD-Cone" target="_blank"><img src="https://badge.fury.io/py/Super-SCAD-Cone.svg" alt="Latest Stable Version"/></a><br/>
</td>
<td>
<a href="https://codecov.io/gh/SuperSCAD/Cone" target="_blank"><img src="https://codecov.io/gh/SuperSCAD/Cone/graph/badge.svg" alt="Code Coverage"/></a>
<a href="https://github.com/SuperSCAD/Cone/actions/workflows/unit.yml"><img src="https://github.com/SuperSCAD/Cone/actions/workflows/unit.yml/badge.svg" alt="Unit Tests"/></a>
</td>
</tr>
</tbody>
</table>

# License

This project is licensed under the terms of the [MIT license](LICENSE).
